import { Multiaddr } from '@multiformats/multiaddr';
import { PeerId } from '@libp2p/peer-id';
import { WebRTCInitiator } from './peer/initiator.js';
import { EventEmitter } from '@libp2p/interfaces';
import type { WRTC } from './peer/interface.js';
import type { Connection } from '@libp2p/interfaces/connection';
import type { Transport, Upgrader, ListenerOptions, MultiaddrConnection, Listener } from '@libp2p/interfaces/transport';
import type { PeerDiscovery } from '@libp2p/interfaces/peer-discovery';
import type { AbortOptions } from '@libp2p/interfaces';
import type { WebRTCInitiatorOptions } from './peer/initiator.js';
import type { WebRTCReceiver, WebRTCReceiverOptions } from './peer/receiver.js';
import type { WebRTCStarSocket, HandshakeSignal } from '@libp2p/webrtc-star-protocol';
export interface WebRTCStarOptions {
    upgrader: Upgrader;
    peerId: PeerId;
    wrtc?: WRTC;
}
export interface WebRTCStarDialOptions extends AbortOptions {
    channelOptions?: WebRTCInitiatorOptions;
}
export interface WebRTCStarListenerOptions extends ListenerOptions, WebRTCInitiatorOptions {
    channelOptions?: WebRTCReceiverOptions;
}
export interface SignalServerServerEvents {
    'error': CustomEvent<Error>;
    'listening': CustomEvent;
    'peer': CustomEvent<string>;
    'connection': CustomEvent<Connection>;
}
export interface SignalServer extends EventEmitter<SignalServerServerEvents> {
    signallingAddr: Multiaddr;
    socket: WebRTCStarSocket;
    connections: MultiaddrConnection[];
    channels: Map<string, WebRTCReceiver>;
    pendingSignals: Map<string, HandshakeSignal[]>;
    close: () => Promise<void>;
}
/**
 * @class WebRTCStar
 */
export declare class WebRTCStar implements Transport<WebRTCStarDialOptions, WebRTCStarListenerOptions> {
    wrtc?: WRTC;
    discovery: PeerDiscovery;
    sigServers: Map<string, SignalServer>;
    private readonly upgrader;
    private readonly peerId;
    constructor(options: WebRTCStarOptions);
    dial(ma: Multiaddr, options?: WebRTCStarDialOptions): Promise<Connection>;
    _connect(ma: Multiaddr, options: WebRTCStarDialOptions): Promise<WebRTCInitiator>;
    /**
     * Creates a WebrtcStar listener. The provided `handler` function will be called
     * anytime a new incoming Connection has been successfully upgraded via
     * `upgrader.upgradeInbound`.
     */
    createListener(options?: WebRTCStarListenerOptions): Listener;
    /**
     * Takes a list of `Multiaddr`s and returns only valid TCP addresses
     */
    filter(multiaddrs: Multiaddr[]): Multiaddr[];
    peerDiscovered(maStr: string): void;
}
//# sourceMappingURL=index.d.ts.map